@@ -9,11 +9,9 @@
 
 #include "mpg123app.h"
 #include <stdarg.h>
-#ifndef WIN32
+#if !defined (WIN32) || defined (__CYGWIN__)
 #include <sys/wait.h>
 #include <sys/socket.h>
-#else
-#include <winsock.h>
 #endif
 #include <fcntl.h>
 #include <errno.h>
@@ -27,6 +25,8 @@
 #define MODE_PAUSED 2
 
 extern int buffer_pid;
+extern audio_output_t *ao;
+
 #ifdef FIFO
 #include <sys/stat.h>
 int control_file = STDIN_FILENO;
@@ -262,7 +262,7 @@ int control_generic (mpg123_handle *fr)
 #endif
 	/* the command behaviour is different, so is the ID */
 	/* now also with version for command availability */
-	fprintf(outstream, "@R MPG123 (ThOr) v5\n");
+	fprintf(outstream, "@R MPG123 (ThOr) v6\n");
 #ifdef FIFO
 	if(param.fifo)
 	{
@@ -455,7 +455,8 @@ int control_generic (mpg123_handle *fr)
 					off_t pos = mpg123_tell(fr);
 					off_t len = mpg123_length(fr);
 					/* I need to have portable printf specifiers that do not truncate the type... more autoconf... */
-					generic_sendmsg("SAMPLE %li %li", (long)pos, (long)len);
+					if(len < 0) generic_sendmsg("E %s", mpg123_strerror(fr));
+					else generic_sendmsg("SAMPLE %li %li", (long)pos, (long)len);
 					continue;
 				}
 
@@ -507,6 +508,7 @@ int control_generic (mpg123_handle *fr)
 					generic_sendmsg("H SCAN: scan through the file, building seek index");
 					generic_sendmsg("H SAMPLE: print out the sample position and total number of samples");
 					generic_sendmsg("H SEQ <bass> <mid> <treble>: simple eq setting...");
+					generic_sendmsg("H PITCH <[+|-]value>: adjust playback speed (+0.01 is 1 %% faster)");
 					generic_sendmsg("H SILENCE: be silent during playback (meaning silence in text form)");
 					generic_sendmsg("H STATE: Print auxilliary state info in several lines (just try it to see what info is there).");
 					generic_sendmsg("H TAG/T: Print all available (ID3) tag info, for ID3v2 that gives output of all collected text fields, using the ID3v2.3/4 4-character names.");
@@ -650,6 +652,19 @@ int control_generic (mpg123_handle *fr)
 						continue;
 					}
 
+					/* PITCH (playback speed) in percent */
+					if(!strcasecmp(cmd, "PITCH"))
+					{
+						double p;
+						if(sscanf(arg, "%lf", &p) == 1)
+						{
+							set_pitch(fr, ao, p);
+							generic_sendmsg("PITCH %f", param.pitch);
+						}
+						else generic_sendmsg("E invalid arguments for PITCH: %s", arg);
+						continue;
+					}
+
 					/* RVA mode */
 					if(!strcasecmp(cmd, "RVA"))
 					{
